@@ -1,16 +1,16 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 #
 # Read iso-codes data file and output a .tab file
 # 
-# Copyright (C) 2004 Alastair McKinstry <mckinstry@debian.org>
+# Copyright (C) 2004,2005 Alastair McKinstry <mckinstry@debian.org>
 # Released under the GPL.
-# $Id: iso3166tab.py,v 1.2 2005/01/08 18:06:46 mckinstry Exp $
+# $Id: iso3166tab.py,v 1.3 2005/10/24 20:21:25 mckinstry Exp $
 
-from xml.sax import saxutils, make_parser, saxlib, saxexts, ContentHandler
-from xml.sax.handler import feature_namespaces
+from xml.sax import make_parser, SAXException, SAXParseException
+from xml.sax.handler import feature_namespaces, ContentHandler
 import sys, os, getopt, urllib2
 
-class printLines(saxutils.DefaultHandler):
+class printLines(ContentHandler):
 	def __init__(self, ofile):
 		self.ofile = ofile
 
@@ -43,14 +43,17 @@ class printLines(saxutils.DefaultHandler):
 
 ofile = sys.stdout
 p = make_parser()
-p.setErrorHandler(saxutils.ErrorPrinter())
 try:
 	dh = printLines(ofile)
 	p.setContentHandler(dh)
 	p.parse(sys.argv[1])
-except IOError,e:
-	print in_sysID+": "+str(e)
-except saxlib.SAXException,e:
-	print str(e)
-
+except SAXParseException, e:
+	sys.stderr.write('%s:%s:%s: %s\n' % (e.getSystemId(),
+		     e.getLineNumber(),
+		     e.getColumnNumber(),
+		     e.getMessage()))
+	sys.exit(1)
+except Exception, e:
+	sys.stderr.write('<unknown>: %s\n' % str(e))
+	sys.exit(1)
 ofile.close()
